@@ -57,21 +57,12 @@ class Compact(ScaleType):
         return self.compact_bytes
 
     def process(self):
-
         self.process_compact_bytes()
 
-        if self.sub_type:
-
-            byte_data = self.runtime_config.create_scale_object(
-                type_string=self.sub_type, data=ScaleBytes(self.compact_bytes)
-            ).process()
-
-            if type(byte_data) is int and self.compact_length <= 4:
-                return int(byte_data / 4)
-            else:
-                return byte_data
+        if self.compact_length <= 4:
+            return int(int.from_bytes(self.compact_bytes, byteorder='little') / 4)
         else:
-            return self.compact_bytes
+            return int.from_bytes(self.compact_bytes, byteorder='little')
 
     def process_encode(self, value):
 
@@ -1286,7 +1277,7 @@ class GenericCall(ScaleType):
             self.call_module = self.metadata.get_pallet_by_index(pallet_index.value)
             call_type_string = self.call_module['calls'].value_object.get_type_string()
 
-            call_obj = self.process_type(call_type_string)
+            call_obj = self.process_type(call_type_string, metadata=self.metadata)
 
             self.call_index = "{:02x}{:02x}".format(pallet_index.value, call_obj.index)
 
@@ -2151,10 +2142,18 @@ class GenericStorageEntryMetadata(Struct):
     def name(self):
         return self.value['name']
 
+    @property
+    def modifier(self):
+        return self.value['modifier']
+
     @property
     def type(self):
         return self.value['type']
 
+    @property
+    def docs(self):
+        return self.value['documentation']
+
     def get_type_string_for_type(self, ty):
         return self.convert_type(ty)
 
@@ -2255,6 +2254,10 @@ class GenericEventMetadata(Struct):
     def args(self):
         return self.value_object['args']
 
+    @property
+    def docs(self):
+        return self.value['documentation']
+
 
 class GenericErrorMetadata(Struct):
 
@@ -2298,7 +2301,10 @@ class ScaleInfoFunctionArgumentMetadata(GenericFunctionArgumentMetadata):
 
     @property
     def type(self):
-        return f"scale_info::{self.value['type']}"
+        if self.value.get('typeName'):
+            return self.value.get('typeName')
+        else:
+            return f"scale_info::{self.value['type']}"
 
 
 class TypeNotSupported(ScaleType):
